Name:          scons
Version:       4.3.0
Release:       1
Summary:       An Open Source software construction tool
License:       MIT
URL:           http://www.scons.org
Source0:       https://github.com/SCons/scons/archive/scons-%{version}.tar.gz
Source1:       https://scons.org/doc/%{version}/scons-doc-%{version}.tar.gz
BuildArch:     noarch
BuildRequires: make

%description
SCons is an Open Source software construction tool—that is, a next-generation
build tool. Think of SCons as an improved, cross-platform substitute for the
classic Make utility with integrated functionality similar to autoconf/automake
and compiler caches such as ccache. In short, SCons is an easier, more reliable
and faster way to build software.

%package        doc
Summary:        An Open Source software construction tool
BuildArch:      noarch

%description    doc
Scons HTML documentation.

%package -n     python3-%{name}
Summary:        An Open Source software construction tool

BuildRequires:  python3-devel
BuildRequires:  python3-lxml
BuildRequires:  python3-wheel
BuildRequires:  python3-setuptools
BuildRequires:  lynx
Provides:       scons = 0:%{version}-%{release}
Provides:       scons-python3
Obsoletes:      scons < 0:5.0.3-3
%{?python_provide:%python_provide python3-%{name}}

%description -n python3-%{name}
SCons is an Open Source software construction tool—that is, a next-generation
build tool. Think of SCons as an improved, cross-platform substitute for the
classic Make utility with integrated functionality similar to autoconf/automake
and compiler caches such as ccache. In short, SCons is an easier, more reliable
and faster way to build software.

%prep
%autosetup -n %{name}-%{version} -N
%setup -n %{name}-%{version} -q -T -D -a 1
cd ..

# Convert to UTF-8
for file in %{name}-%{version}/src/*.txt; do
    iconv -f ISO-8859-1 -t UTF-8 -o $file.new $file && \
    touch -r $file $file.new && \
    mv $file.new $file
done

sed -i -e 's!env.AddPostAction(tgz_file, Delete(man_pages))! !g' %{name}-%{version}/SConstruct

pathfix.py -i %{__python3} -pn %{name}-%{version}/scripts/scons.py

###cp -a %{name}-%{version} %{name}-%{version}-py3
###sed -i 's|/usr/bin/env python|%{__python3}|' %{name}-%{version}-py3/scripts/scons.py

%build
%{__python3} scripts/scons.py

%install
export LDFLAGS="%{build_ldflags}"
export CFLAGS="%{build_cflags}"

%{_bindir}/python3 setup.py install -O1 --skip-build --root %{buildroot} \
 --install-scripts=%{_bindir} \
 --install-data=%{_datadir}

# Install manpages
mkdir -p %{buildroot}%{_mandir}/man1
install -pm 644 build/doc/man/*.1 %{buildroot}%{_mandir}/man1/
rm -f %{buildroot}%{_datadir}/*.1

pushd %{buildroot}%{_bindir}  
for i in %{name}-3 %{name}-v%{version}-%{python3_version} %{name}-%{python3_version}; do
  ln -fs %{_bindir}/%{name} %{buildroot}%{_bindir}/$i
done
for i in %{name}ign-3 %{name}ign-v%{version}-%{python3_version} %{name}ign-%{python3_version}; do
  ln -fs %{_bindir}/%{name}ign %{buildroot}%{_bindir}/$i
done
for i in %{name}-time-3 %{name}-time-v%{version}-%{python3_version} %{name}-time-%{python3_version}; do
  ln -fs %{_bindir}/%{name}-time %{buildroot}%{_bindir}/$i
done
for i in %{name}-configure-cache-3 %{name}-configure-cache-v%{version}-%{python3_version} %{name}-configure-cache-%{python3_version}; do
  ln -fs %{_bindir}/%{name}-configure-cache %{buildroot}%{_bindir}/$i
done
popd

%check
%{__python3} runtest.py -P %{__python3} --passed --quit-on-failure SCons/BuilderTests.py

%files -n python3-%{name}
%doc CHANGES.txt RELEASE.*
%license LICENSE*
%{_bindir}/%{name}*-3
%{_bindir}/%{name}
%{_bindir}/%{name}{ign,-time,-configure-cache}
%{_bindir}/%{name}*-%{python3_version}
%{python3_sitelib}/SCons/
%{python3_sitelib}/*.egg-info
%{_mandir}/man1/*

%files doc
%doc HTML PDF EPUB TEXT

%changelog
* Fri Jun 10 2022 SimpleUpdate Robot <tc@openeuler.org> - 4.3.0-1
- Upgrade to version 4.3.0

* Wed Dec 23 2020 lingsheng <lingsheng@huawei.com> - 3.1.1-4
- Keep spec name same as package

* Tue Oct 20 2020 zhanghua <zhanghua40@huawei.com> -  3.1.1-3
- remove python2 subpackage

* Thu Jun 4 2020 Captain Wei <captain.a.wei@gmail.com> - 3.1.1-2
- update package version

* Sat Nov 30 2019 zhouyihang <zhouyihang1@huawei.com> - 3.0.1-10
- Package init
